Changelog
=========

4.1.5 (2017-02-12)
------------------

Bug fixes:

- Don't instantiate browser view to check for existence.
  [malthe]


4.1.4 (2016-05-06)
------------------

Bug fixes:

- Removed docstrings from some methods to avoid publishing them.  From
  Products.PloneHotfix20160419.  [maurits]


4.1.3 (2015-07-29)
------------------

- Cleanup: PEP8 et al., security/zca via decorators, ...
  [jensens]


4.1.2 (2015-06-03)
------------------

- Fix https://github.com/plone/Products.CMFPlone/issues/591
  [gotcha]


4.1.1 (2015-05-13)
------------------

- Removed CMFDefault dependency
  [tomgross]

4.1.0 (2015-03-17)
------------------

- When a default object is used as layout for a container,
  if the default object is deleted or moved with cut and paste,
  reset the default_page property of the container.
  [gotcha]

- When a default object is used as layout for a container,
  if the default object is renamed (iow id is changed),
  fix the default_page property of the container.
  [gotcha]

4.0.6 (2015-03-13)
------------------

- Ported tests to plone.app.testing
  [tomgross]

- Removed BBB interface.py module
  [tomgross]

- pep8ify
  [tomgross]


4.0.5 (2013-05-23)
------------------

- Add i18n translation domain to the zcml to remove UserWarning.


4.0.4 (2013-04-06)
------------------

- Add cmf.ModifyViewTemplate zcml permission for "Modify view template"
  [toutpt]

4.0.3 (2012-08-29)
------------------

- Import from zope.browsermenu.
  [hannosch]

4.0.2 - 2011-03-28
------------------

- Revert the BrowserDefaultMixin.__browser_default__ change, it is
  unnecessary. Instead set the ``(Default)`` view alias to ``(dynamic view)``.
  [elro]

4.0.1 - 2011-03-28
------------------

- Provide BrowserDefaultMixin.__browser_default__ so subclasses do not have to
  provide their own.
  [elro]

- Fix BrowserDefaultMixin.__call__ (never normally used in vanilla Plone) to
  work with views. [elro]

- Avoid deprecation warning in Zope 2.13.
  [davisagli]

- Fixed test setup to work with ZCA-based GenericSetup profile registry.
  [davisagli]

4.0 - 2010-07-18
----------------

- No changes.

4.0b1 - 2009-12-27
------------------

- Removed BBB code for CMF prior to 1.6 and fixed import errors in tests.
  [hannosch]

4.0a1 - 2009-11-13
------------------

- Fixed dependency on zope.app.container for the IAdding interface.
  [hannosch]

- Don't use `manage_page_` macros anymore.
  [hannosch]

- Standardized the interface location to an interfaces module.
  [hannosch]

- Updated package metadata.
  [hannosch]

- Declared package dependencies and fixed deprecation warnings for use
  of Globals.
  [hannosch]

- Purged old Zope 2 Interface interfaces for Zope 2.12 compatibility.
  [elro]

3.0.3 - unreleased
------------------

- Adjusted deprecation warnings to point to Plone 4.0 instead of Plone 3.5
  since we changed the version numbering again.
  [hannosch]

3.0.2 - 2008-03-26
------------------

- Made tests compatible with CMF 2.2.
  [hannosch]

3.0.1 - 2007-10-07
------------------

- Copied addWithPresettings.pt from GenericSetup 1.3 branch r79408. This
  fixes a startup error in buildouts caused by the move to an egg.
  [fschulze]

- Adding a Dynamic View FTI through ZMI is back. This closes
  https://dev.plone.org/plone/ticket/6976
  [glenfant]

- Removed migrate module, which didn't work in CMF 2.1 anymore. Use
  GenericSetup profiles for handling portal types instead. This closes
  http://dev.plone.org/plone/ticket/6899.
  [hannosch]

3.0 - 2007-08-09
----------------

- No changes.
  [hannosch]

3.0rc1 - 2007-07-09
-------------------

- Removed some BBB code.
  [hannosch]

- Removed five:registerPackage.
  [hannosch]

3.0b1 - 2007-05-01
------------------

- Updated some import locations. We require a minimum of Zope 2.10 now.
  [hannosch]

- Rename menus - turns out dotted names don't really work with the ZCML
  magic that's creating interfaces on the fly (it's akin to having a
  variable name with a dot in it)
  [optilude]

- Use new displayviews menu to find view titles; rework Z3 view test to use
  a test zcml file.
  [mj]

2.1.2 - 2007-04-22
------------------

- Removed bogus test setup. All the stuff is done by the layer anyway.
  [stefan]

- Removed tests/runalltests.py and tests/framework.py.
  To run tests use Zope's testrunner:
  ./bin/zopectl test --nowarn -s Products.CMFDynamicViewFTI
  [stefan]

2.1.1 - 2007-02-10
------------------

- Removed the view alias of index.html, as this would block uploading of
  files called index.html into folders. You can enable this in your own
  types if you want.
  [hannosch]

2.1.0 - 2006-09-08
------------------

- Implemented fallback to default view:
  If a selected view (i.e. template) does not exist, return the
  default view instead of - ultimately - NotFound. You can enable this
  option by setting the FTI's new 'default_view_fallback' property to True.
  [stefan]

- Converted dummy test sample types to be extension profile based. This
  profile is only registered during test runs.
  [hannosch]

- Slightly adjusted the tests to new CTC version.
  [hannosch]

2.0.0 - 2006-05-15
------------------

- Merged z3-views-integration branch.
  [svincic]

- Making use of Zope 3 interfaces with proper reverse bridges.
  [optilude]

- Fix tests to pass if Five/Zope3 is installed.
  [hannosch]

1.0.4 - 2006-03-19
------------------

- Made 'safe_callable' truly safe by using 'safe_hasattr'.
- Made tests use CMFTestCase. There is no Plone dependency whatsoever.
- Fixed a bug in getViewMethod. A present, but empty 'layout' attribute
  now also returns the default view instead of ''. Returning the empty
  string sends PortalContent.__call__() into a loop.
  [stefan]

1.0.3 - 2006-02-25
------------------

- Added conditional import for typeClasses to make the code CMF1.6
  compatible while staying CMF1.5 backwards compatible.
  [hannosch]

1.0.2 - 2005-12-18
------------------

- Change getViewMethod's 'enforce_available' argument to default to False
  instead of True. If someone goes to the trouble of either using python
  or adding a property to indicate a specific template as the default
  layout, we should let them.
  [rafrombrc]

1.0.1 - 2005-08-09
------------------

- Improved Plone 2.1 integration: getDefaultPage. Replace try/except with a
  better checking for Plone. Bonus: whitespaces cleanup.
  [deo]

- Stop Acquisition for default_page.
  [panjunyong]

1.0.0 - 2005-07-29
------------------

- Initial release.
